file_read_backwards package
===========================

Submodules
----------

file_read_backwards.file_read_backwards module
----------------------------------------------

.. automodule:: file_read_backwards.file_read_backwards
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: file_read_backwards
    :members:
    :undoc-members:
    :show-inheritance:
